@@ -1,6 +1,6 @@
 package MARC::Moose::Record;
 BEGIN {
-  $MARC::Moose::Record::VERSION = '0.015';
+  $MARC::Moose::Record::VERSION = '0.016';
 }
 # ABSTRACT: MARC::Moose bibliographic record
 
@@ -75,22 +75,30 @@ sub set_leader_length {
 
 
 sub append {
-    my ($self, $field_to_add) = @_;
+    my $self = shift;
 
+    my @fields = @_;
+    return unless @fields;
+        
     # Control field correctness
-    carp  "Append a non MARC::Moose::Field"
-        unless ref($field_to_add) =~ /^MARC::Moose::Field/; 
+    for my $field (@fields) {
+        unless ( ref($field) =~ /^MARC::Moose::Field/ ) {
+            carp  "Append a non MARC::Moose::Field";
+            return;
+        }
+    }
 
-    my $tag = $field_to_add->tag;
+    my $tag = $fields[0]->tag;
     my @sf;
+    my $notdone = 1; 
     for my $field ( @{$self->fields} ) {
-        if ( $field_to_add and $field->tag gt $tag ) {
-            push @sf, $field_to_add;
-            $field_to_add = undef;
+        if ( $notdone && $field->tag gt $tag ) {
+            push @sf, @fields;
+            $notdone = 0;
         }
         push @sf, $field;
     }
-    push @sf, $field_to_add if $field_to_add;
+    push @sf, @fields if $notdone;
     $self->fields( \@sf );
 }
 
@@ -165,7 +173,7 @@ MARC::Moose::Record - MARC::Moose bibliographic record
 
 =head1 VERSION
 
-version 0.015
+version 0.016
 
 =head1 DESCRIPTION
 
@@ -199,6 +207,10 @@ fields list.
               [ u => 'Translation' ] ]
  ) );
 
+You can also append an array of MARC::Moose::Field. In this case, the array
+will be appended as for a unique field at the position of the first field of
+the array.
+
 =head2 field( I<tag> )
 
 Returns a list of tags that match the field specifier, or an empty list if
